@@ -22,7 +22,6 @@
 bs_get_follow_suggestions <- function(actor,
                                       user = get_bluesky_user(), pass = get_bluesky_pass(),
                                       auth = bs_auth(user, pass), clean = TRUE) {
-
   req <- httr2::request('https://bsky.social/xrpc/app.bsky.graph.getSuggestedFollowsByActor') |>
     httr2::req_url_query(actor = actor) |>
     httr2::req_auth_bearer_token(token = auth$accessJwt)
@@ -31,7 +30,9 @@ bs_get_follow_suggestions <- function(actor,
     httr2::req_perform() |>
     httr2::resp_body_json()
 
-  if (!clean) return(resp)
+  if (!clean) {
+    return(resp)
+  }
 
   resp |>
     purrr::pluck('suggestions') |>
