@@ -1,3 +1,3 @@
-test_that("time creation works", {
+test_that('time creation works', {
   expect_equal(nchar(bs_created_at()), 27)
 })
